import { Observable } from 'rxjs';
/**
 * Provides detyped notifications of changes in application state.
 *
 * It is recommended that all components and services broadcast events
 * that may be of interest to others. There is no overhead to broadcasting
 * an event that no one is subscribed to.
 *
 * Any events broadcast should be documented as part of the modules API.
 *
 * Example
 * -------
 *
 * In this example we broadcast an event of type cheese and have the mouse
 * subscribe to it.
 *
 *
 *     constructor(
 *       private broadcaster: Broadcaster
 *     )
 *
 *     ngOnInit() {
 *       broadcaster.on<Cheese>('cheese').subscribe(val => this.mouse.eatCheese(val));
 *     }
 *
 *     newCheese() {
 *       broadcaster.broadcast('cheese', { type: 'cheddar' } as Cheese);
 *     }
 *
 */
export declare class Broadcaster {
    private _eventBus;
    constructor();
    /**
     * Broadcast an event.
     *
     * @param key the key to broadcast the event for. Normally we use a string.
     * @param data the payload to send.
     */
    broadcast(key: any, data?: any): void;
    /**
     * Observe an event.
     *
     * @param key the key to observe the event for.
     * @returns an Observable to which you can subscribe or use any RxJS operator.
     *
     */
    on<T>(key: any): Observable<T>;
}
