import { Injectable } from '@angular/core';
import { Subject } from 'rxjs';
import { filter, map } from 'rxjs/operators';
/**
 * Provides detyped notifications of changes in application state.
 *
 * It is recommended that all components and services broadcast events
 * that may be of interest to others. There is no overhead to broadcasting
 * an event that no one is subscribed to.
 *
 * Any events broadcast should be documented as part of the modules API.
 *
 * Example
 * -------
 *
 * In this example we broadcast an event of type cheese and have the mouse
 * subscribe to it.
 *
 *
 *     constructor(
 *       private broadcaster: Broadcaster
 *     )
 *
 *     ngOnInit() {
 *       broadcaster.on<Cheese>('cheese').subscribe(val => this.mouse.eatCheese(val));
 *     }
 *
 *     newCheese() {
 *       broadcaster.broadcast('cheese', { type: 'cheddar' } as Cheese);
 *     }
 *
 */
var Broadcaster = /** @class */ (function () {
    function Broadcaster() {
        this._eventBus = new Subject();
    }
    /**
     * Broadcast an event.
     *
     * @param key the key to broadcast the event for. Normally we use a string.
     * @param data the payload to send.
     */
    Broadcaster.prototype.broadcast = function (key, data) {
        this._eventBus.next({ key: key, data: data });
    };
    /**
     * Observe an event.
     *
     * @param key the key to observe the event for.
     * @returns an Observable to which you can subscribe or use any RxJS operator.
     *
     */
    Broadcaster.prototype.on = function (key) {
        return this._eventBus.asObservable()
            .pipe(filter(function (event) { return event.key === key; }), map(function (event) { return event.data; }));
    };
    Broadcaster.decorators = [
        { type: Injectable, args: [{
                    providedIn: 'root'
                },] },
    ];
    /** @nocollapse */
    Broadcaster.ctorParameters = function () { return []; };
    return Broadcaster;
}());
export { Broadcaster };
//# sourceMappingURL=broadcaster.service.js.map